======================
codelab_adapter_client
======================


.. image:: https://img.shields.io/pypi/v/codelab_adapter_client.svg
        :target: https://pypi.python.org/pypi/codelab_adapter_client

.. image:: https://img.shields.io/travis/wwj718/codelab_adapter_client.svg
        :target: https://travis-ci.org/wwj718/codelab_adapter_client

.. image:: https://readthedocs.org/projects/codelab-adapter-client/badge/?version=latest
        :target: https://codelab-adapter-client.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status


Python Client of CodeLab Adapter(https://adapter.codelab.club/) v2.


Install
-------

pip install codelab_adapter_client


Usage
-----

from codelab_adapter_client import AdapterNode

example
-------

https://github.com/wwj718/codelab_adapter_client/blob/master/examples/extension_eim.py


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
